function AxialView
global k
MakeAxialItems           % create all objects appearing on tab "Axial View"
if k.i==0
    initializeAxial
end
end
function MakeAxialItems
global g main
    
g.AxialAxes = axes('Position',[0.03 0.3 0.65 0.65],'Units','normalized','Parent',main.panels(main.av),...
                   'box','on','DataAspectRatio',[1 1 1]);   %,'Xlim',[0 0.45],'Ylim',[-0.05 0.3]
g.AxialFig=gca;
set(g.AxialFig,'ButtonDownFcn',@GetPoint);

g.nsEdit=uicontrol('Style', 'edit','Units', 'normalized','position', [0.81 0.85 0.05 0.03],...
                   'Callback', @nsEditCallback,'Parent',main.panels(main.av));
g.nsSlider=uicontrol('Style', 'slider', 'Units', 'normalized','position',[0.87 0.85 0.01 0.027],...
                     'Min',3,'Max',50,'Callback', @nsSliderCallback,'Parent',main.panels(main.av));
g.nsStatic=uicontrol('Style','text','HorizontalAlignment','left','String','Streamlines','FontSize',12,'Units','normalized',...
                     'BackgroundColor',[.8 .8 .8],'position',[0.74 0.847 0.05 0.03],...
                     'Parent',main.panels(main.av));
                                
g.bStatic=uicontrol('Style','text','HorizontalAlignment','left','String','b','FontSize',12,'Units','normalized',...
                     'BackgroundColor',[.8 .8 .8],'position',[0.74 0.797 0.05 0.03],...
                     'Parent',main.panels(main.av));
g.bEdit=uicontrol('Style', 'edit','Units', 'normalized','position', [0.81 0.80 0.05 0.03],...
                   'Callback', @bEditCallback,'Parent',main.panels(main.av));
g.bSlider=uicontrol('Style', 'slider', 'Units', 'normalized','position',[0.87 0.80 0.01 0.027],...
                    'Callback', @bSliderCallback,'Parent',main.panels(main.av)); 
                
g.InitialButton=uicontrol('Style', 'pushbutton', 'String', 'Reset plot', 'Units', 'normalized','FontSize', 12,...
                        'position', [0.75 0.90 0.10 0.05],'Callback', @InitialCallback,...
                        'Parent',main.panels(main.av),'enable','on'); 
                    
g.UpdateButton=uicontrol('Style', 'pushbutton', 'String', 'Update Design', 'Units','normalized','FontSize', 12,...
                        'position', [0.75 0.60 0.10 0.05],'Callback', @UpdateCallback,...
                        'Parent',main.panels(main.av),'enable','on');

g.ShroudCheck=uicontrol('Style', 'checkbox', 'String', 'Shroud', 'Units', 'normalized','FontSize', 12,...
                        'position', [0.15 0.20 0.20 0.05],'Callback', @ShroudCallback,...
                        'Parent',main.panels(main.av),'Value',1,'BackgroundColor',[.8 .8 .8]);
g.OutletCheck=uicontrol('Style', 'checkbox', 'String', 'Trailing edge', 'Units', 'normalized','FontSize', 12,...
                        'position', [0.35 0.20 0.20 0.05],'Callback', @OutletCallback,...
                        'Parent',main.panels(main.av),'Value',0,'BackgroundColor',[.8 .8 .8]);                    
                    
g.UserStatic=uicontrol('Style','text','HorizontalAlignment','left','String','The streamline along the shroud is governed by a bezier curve with five control points. The three points in the middle can be moved to alter the shape of the curve. When clicking inside the graph, a graticule appears. When clicking once more in the graph, the control point closest to the graticule is chosen. Then the point can be moved around using the arrow buttons on the keyboard.','FontSize',12,'Units','normalized',...
                     'BackgroundColor',[.8 .8 .8],'position',[0.64 0.40 0.35 0.10],...
                     'Parent',main.panels(main.av));
g.User2Static=uicontrol('Style','text','HorizontalAlignment','left','String','The trailing edge shape is also governed by a Bezier curve, but for this all four points can be moved.','FontSize',12,'Units','normalized',...
                     'BackgroundColor',[.8 .8 .8],'position',[0.64 0.29 0.35 0.10],...
                     'Parent',main.panels(main.av));
g.User3Static=uicontrol('Style','text','HorizontalAlignment','left','String','The number of streamlines and the height difference between inlet and outletcan be changed by either entering the desired number or clicking on the sliders.','FontSize',12,'Units','normalized',...
                     'BackgroundColor',[.8 .8 .8],'position',[0.64 0.24 0.35 0.10],...
                     'Parent',main.panels(main.av));
g.User4Static=uicontrol('Style','text','HorizontalAlignment','left','String','The Reset Plot-button resets the axial view to the initial shape','FontSize',12,'Units','normalized',...
                     'BackgroundColor',[.8 .8 .8],'position',[0.64 0.18 0.35 0.10],...
                     'Parent',main.panels(main.av));                 
end

function initializeAxial
global g 
ns=10;  % initial value of number of streamlines
maxns=50; minns=3;
set(g.nsEdit,'String',num2str(ns));
set(g.nsSlider,'Value',ns,'Max',maxns,'Min',minns,'SliderStep',[1/(maxns-minns) 1/(maxns-minns)]);

b=0.16;
maxb=3*b; minb=0.3*b;
set(g.bEdit,'String',num2str(b));
set(g.bSlider,'Value',b,'Max',maxb,'Min',minb,'SliderStep',[0.01/(maxb-minb) 0.01/(maxb-minb)]);
end

function InitialCallback(~,~)
global g
g.b=get(g.bSlider,'Value');
    g.ps0=[g.D_1/2, g.b];
    g.ps4=[g.D_2/2, 0.005];  
    g.ps1=[g.D_1/2-2*(g.D_1-g.D_2)/10, g.b*9/10];
    g.ps2=[g.D_1/2-4*(g.D_1-g.D_2)/10, g.b*8/10];
    g.ps3=[g.D_2/2, g.b/10];
    g.shroud=[g.ps0; g.ps1; g.ps2; g.ps3; g.ps4];
    plotAxialView(1)
end

function OutletCallback(~,~)
global g
a=get(g.ShroudCheck,'Value');
a=abs(a-1);
set(g.ShroudCheck,'Value',a);
end
function ShroudCallback(~,~)
global g
a=get(g.OutletCheck,'Value');
a=abs(a-1);
set(g.OutletCheck,'Value',a);
end
function UpdateCallback(~,~)
global g
UpdateDistribution(g.UpdateCount)
g.UpdateCount=g.UpdateCount+1;
end

function nsEditCallback(~,~)
global g
sliderValue = get(g.nsEdit,'String');
sliderValue = str2double(sliderValue);
%if user input is not a number, or if the input is less than min
%or greater than max, then the slider value defaults to min
if (isempty(sliderValue) || sliderValue < get(g.nsSlider,'Min') || sliderValue > get(g.nsSlider,'Max'))
    set(g.nsSlider,'Value',get(g.nsSlider,'Min'));
    set(g.nsEdit,'String',num2str(get(g.nsSlider,'Min')));
else
    set(g.nsSlider,'Value',sliderValue);
end
set(g.InitialButton,'enable','on');
plotAxialView(0)
end
function nsSliderCallback(hobj,~)
global g 
sliderValue = get(g.nsSlider,'Value');
sliderValue = num2str(sliderValue);
set(g.nsEdit,'String',sliderValue);
set(g.InitialButton,'enable','on');
plotAxialView(0)
guidata(hobj, g);
end

function bEditCallback(~,~)
global g
sliderValue = get(g.bEdit,'String');
sliderValue = str2double(sliderValue);
%if user input is not a number, or if the input is less than min
%or greater than max, then the slider value defaults to min
if (isempty(sliderValue) || sliderValue < get(g.bSlider,'Min') || sliderValue > get(g.bSlider,'Max'))
    set(g.bSlider,'Value',get(g.bSlider,'Min'));
    set(g.bEdit,'String',num2str(get(g.bSlider,'Min')));
else
    set(g.bSlider,'Value',sliderValue);
end
set(g.InitialButton,'enable','on');
g.b=get(g.bSlider,'Value');
    g.ps0=[g.D_1/2, g.b];
    g.ps4=[g.D_2/2, 0.005];  
    g.ps1=[g.D_1/2-2*(g.D_1-g.D_2)/10, g.b*9/10];
    g.ps2=[g.D_1/2-4*(g.D_1-g.D_2)/10, g.b*8/10];
    g.ps3=[g.D_2/2, g.b/10];
g.shroud=[g.ps0; g.ps1; g.ps2; g.ps3; g.ps4];
plotAxialView(1)
end
function bSliderCallback(hobj,~)
global g 
sliderValue = get(g.bSlider,'Value');
sliderValue = num2str(sliderValue);
set(g.bEdit,'String',sliderValue);
set(g.InitialButton,'enable','on');
g.b=get(g.bSlider,'Value');
    g.ps0=[g.D_1/2, g.b];
    g.ps4=[g.D_2/2, 0.005];  
    g.ps1=[g.D_1/2-2*(g.D_1-g.D_2)/10, g.b*9/10];
    g.ps2=[g.D_1/2-4*(g.D_1-g.D_2)/10, g.b*8/10];
    g.ps3=[g.D_2/2, g.b/10];
    g.shroud=[g.ps0; g.ps1; g.ps2; g.ps3; g.ps4];
plotAxialView(1)    
guidata(hobj, g);
end

function GetPoint(~,~)
    global g
    [x,~]=ginput(1);
    a=get(g.ShroudCheck,'Value');
    if a==1
        try delete(g.OutletDotPlot); end
        ypoint=interp1(g.shroud(2:end-1,1),g.shroud(2:end-1,2),x,'nearest');
        xpoint=interp1(g.shroud(2:end-1,1),g.shroud(2:end-1,1),x,'nearest');
        index=find(g.shroud(2:end)==xpoint,1)+1;
        try delete(g.ShroudDotPlot); end
        g.ShroudDotPlot=plot(g.AxialFig,xpoint,ypoint,'marker','s','markersize',5,'markerfacecolor','r');
        set(gcf,'KeyPressFcn',{@figure_keypress,index});
    else
        try delete(g.ShroudDotPlot); end
        [x,~]=ginput(1);
        ypoint=interp1(g.outlet(:,1),g.outlet(:,2),x,'nearest');
        xpoint=interp1(g.outlet(:,1),g.outlet(:,1),x,'nearest');
        index=find(g.outlet(1:end)==xpoint,1);
        try delete(g.OutletDotPlot); end
        g.OutletDotPlot=plot(g.AxialFig,xpoint,ypoint,'marker','s','markersize',5,'markerfacecolor','r');
        set(gcf,'KeyPressFcn',{@figure_keypress,index});
    end
end
function figure_keypress(~,evdt,index)
    global g main
    a=get(g.ShroudCheck,'Value');
    if a==1
        try delete(g.ShroudDotPlot);end
        dx=0; dy=0;
        if uint8(evdt.Character == 30)
            dy=main.dy;
        elseif uint8(evdt.Character == 31)
            dy=-main.dy;
        elseif uint8(evdt.Character == 28)
            dx=-main.dx; 
        elseif uint8(evdt.Character == 29)
            dx=main.dx;
        end
    
        g.shroud(index,2)=g.shroud(index,2)+dy;
        g.shroud(index,1)=g.shroud(index,1)+dx;
        g.XY100=func_BezierCurve(g.shroud, 100);
        g.XY=func_DistributeEvenly(g.XY100, g.ptemp);
        try delete(g.ShroudLinePlot);end
        try delete(g.ShroudPointPlot);end
        hold on
        g.ShroudLinePlot=plot(g.XY(:,1),g.XY(:,2),'-c');     % plotting the bezier curve
        g.ShroudPointPlot=plot(g.shroud(:,1),g.shroud(:,2),'marker','s','markersize',5,'markerfacecolor','c','linestyle','none');
        g.ShroudDotPlot=plot(g.shroud(index,1),g.shroud(index,2),'marker','s','markersize',5,'markerfacecolor','r');
        plotAxialView(0)
    else
        try delete(g.OutletDotPlot);end
        dx=0; dy=0;
        if uint8(evdt.Character == 30)
            dy=main.dy;
        elseif uint8(evdt.Character == 31)
            dy=-main.dy;
        elseif uint8(evdt.Character == 28)
            dx=-main.dx; 
        elseif uint8(evdt.Character == 29)
            dx=main.dx;
        end
        
        g.outlet(index,2)=g.outlet(index,2)+dy;
        g.outlet(index,1)=g.outlet(index,1)+dx;
        g.outletLine=func_BezierCurve(g.outlet, 100);    
        set(gcf,'CurrentAxes',g.AxialFig);
        hold on
        try delete (g.OutletPointPlot);end
        try delete (g.OutletLinePlot);end
        g.OutletLinePlot=plot(g.outletLine(:,1),g.outletLine(:,2),'-g');    % plotting the bezier curve
        g.OutletPointPlot=plot(g.outlet(:,1),g.outlet(:,2),'marker','s','markersize',5,'markerfacecolor','g','linestyle','none');
        g.OutletDotPlot=plot(g.outlet(index,1),g.outlet(index,2),'marker','s','markersize',5,'markerfacecolor','r');
        plotAxialView(0)
    end
end

